#!/bin/bash
#
# Copyright 2016 Cohesity Inc.
#
# Author: Sachin Gaikwad (sachin@cohesity.com)
#
# Description:
# This script unmounts all NAS/volume mountpoints.
#
# Note: This script does not account if NAS or Volume mounts were done with
# 'persistent' flag i.e. for kroll like applications. It unmounts all NAS/volume
# mountpoints linux_agent_exec has ever done.
#

# ----------------------------------------------------------------------------

f_unmount_dir() {
  dname=$1
  echo "Unmounting $dname"
  umount -f $dname
  retstatus=$?
  if [[ "$retstatus" != "0" ]];
  then
    echo "umount -f failed with $retstatus for mountpoint=$dname"
    return $retstatus
  fi
}

# ----------------------------------------------------------------------------

#
# Executation starts here.
#

CURRENT_DIR=$(dirname `readlink -f $0`)

# Source helper scripts.
. $CURRENT_DIR/common.sh

if [[ $UID != 0 ]]; then
  echo "Please start the script as root or sudo!"
  exit 1
fi

exit_status=0

# Order:
# unmount all volume mountpoints
# unmount all NFS mountpoints
# TODO(sachin): This script does not support unmounting LVM volumes yet. If
# linux agent is used in future to restore to LVM volumes, we will need to add
# support to unmounted LVM mountpoints in correct order (dmsetup devices,
# losetup devices, etc. in correct order).

# See following flags values in agents/linux/flags.cc
#  - linux_agent_nfs_identifier
#  - linux_agent_vmfs_identifier
agent_vol_pattern="agent_vmfs"
agent_nfs_pattern="agent_nfs"

# Fetch all loop mount points that are at '/dev/loop<num>'
# and belong to Agent: agent_vol_pattern.
loop_remote_mounts=$(cat /proc/mounts | grep "/dev/loop" | grep ${agent_vol_pattern} | grep agent | grep tmp | cut -d' ' -f2)

echo "Unmounting guest OS volume mountpoints."
for mount in $loop_remote_mounts;
do
  f_unmount_dir ${mount}
  if [ $? -ne 0 ]; then
    exit_status=$?
  fi
done

echo "Unmounting NFS mountpoints."
mounts=$(cat /proc/mounts | grep ${agent_nfs_pattern} | grep agent | grep tmp | cut -d' ' -f2)
for mount in $mounts;
do
  f_unmount_dir ${mount}
  if [ $? -ne 0 ]; then
    exit_status=$?
  fi
done

echo "Unmounting old mountpoints done"
exit $exit_status
