#!/bin/bash
#
# Copyright 2019 Cohesity Inc.
#
# Author: Nishant Gupta (nishant.gupta@cohesity.com)
# Description:
# This is a wrapper script which takes care of the init system in use
# and launch appropriate commands for start/stop/status behind the scenes
#
# Usage:
# cohesity_linux_agent.sh start
# cohesity_linux_agent.sh stop
# cohesity_linux_agent.sh status

init_type=$(cat -e /sbin/init | grep -waoe 'upstart\|sysvinit\|systemd' | head -n1)

# ----------------------------------------------------------------------------
f_run_command() {
  command_to_run=$1
  case "$init_type" in
        upstart)
          sudo initctl $command_to_run cohesity-agent
          ;;
        systemd)
          sudo systemctl $command_to_run cohesity-agent
          ;;
        *)
          sudo service cohesity-agent $command_to_run
  esac

}

# ----------------------------------------------------------------------------
f_start() {
  f_run_command start
}

# ----------------------------------------------------------------------------
f_stop() {
  f_run_command stop
}

# ----------------------------------------------------------------------------
f_status() {
  f_run_command status
}

# ----------------------------------------------------------------------------
case "$1" in
  start)
    f_start
    ;;
  stop)
    f_stop
    ;;
  status)
    f_status
    ;;
  *)
    echo "Usage: $0 {start|stop|status}"
    exit 1
esac
exit 0
