/**
 * Copyright 2019 Cohesity Inc.
 *
 * Author : Steve Lee
 *
 * Return information from joining backup set and backup piece.
 *
 * This will return all backup sets even if backup piece is not there because
 * it is a LEFT JOIN like operation. We do not directly use "LEFT OUER JOIN"
 * due to oracle's limitation on querying dynamic performance view
 * https://docs.oracle.com/en/database/oracle/oracle-database/19/refrn/
 * about-dynamic-performance-views.html
 * #GUID-F66BEE0B-8091-48A3-975B-376D23B8B4E8
 */
define task_id = &3
define tag = &6
define common_path = '&5'
@"&common_path/common.sql"
select /*+ RULE*/
  bs.BS_KEY,
  bs.CONTROLFILE_INCLUDED,
  bp.HANDLE,
  bp.RECID,
  bp.STATUS,
  bp.TAG,
  bp.BYTES
from V$BACKUP_SET_DETAILS bs, V$BACKUP_PIECE bp
where (bs.SESSION_RECID, bs.SESSION_STAMP) in (
      select /*+ RULE*/distinct SESSION_RECID, SESSION_STAMP
      from V$RMAN_STATUS
      where command_id='&task_id') and
      bp.TAG = UPPER('&tag') and
      bs.SET_STAMP = bp.SET_STAMP(+) and
      bs.SET_COUNT = bp.SET_COUNT(+)
order by bs.BS_KEY;
quit;
