/**
 * Copyright 2019 Cohesity Inc.
 *
 * Author : Steve Lee
 *
 * Return information from joining backupset and archived logs backedup by RMAN.
 *
 * This will return all backup sets even if redolog is not there because it is a
 * LEFT JOIN like operation, we do not directly use "LEFT OUER JOIN" due to
 * oracle's limitation on querying dynamic performance view
 * https://docs.oracle.com/en/database/oracle/oracle-database/19/refrn/
 * about-dynamic-performance-views.html
 * #GUID-F66BEE0B-8091-48A3-975B-376D23B8B4E8
 */
define task_id = &3
define common_path = '&5'
@"&common_path/common.sql"
select /*+ RULE*/
  bs.BS_KEY,
  bs.CONTROLFILE_INCLUDED,
  rl.thread#,
  rl.sequence#,
  rl.resetlogs_change#,
  to_char(cast(rl.RESETLOGS_TIME as timestamp) at time zone 'UTC', '&date_format'),
  rl.FIRST_CHANGE#,
  to_char(cast(rl.FIRST_TIME as timestamp) at time zone 'UTC', '&date_format'),
  rl.NEXT_CHANGE#,
  to_char(cast(rl.NEXT_TIME as timestamp) at time zone 'UTC', '&date_format'),
  rl.NEXT_TIME,
  (select  /*+ RULE*/ resetlogs_id from V$DATABASE_INCARNATION di where di.RESETLOGS_TIME=rl.RESETLOGS_TIME)
from V$BACKUP_SET_DETAILS bs, V$BACKUP_REDOLOG rl
where bs.set_stamp = rl.set_stamp(+) and
      bs.set_count = rl.set_count(+) and
     (bs.SESSION_RECID, bs.SESSION_STAMP) in (
      select /*+ RULE*/distinct SESSION_RECID, SESSION_STAMP
      from V$RMAN_STATUS
      where command_id='&task_id')
order by bs.BS_KEY;
quit;
