/**
 * Copyright 2020 Cohesity Inc.
 *
 * Author : Qing Wan
 *
 * Get the datafile information for the current command ID from backupset.
 * task_id is command_id since using tag will get all previous backup
 * of datafiles
 * use SESSION_RECID/SESSION_STAMP as identifier to find target
 * backuppieces for datatfiles, same way we used to find for controlfiles,
 * archive logs.
 * TODO: provide unified script to retrive metadata for datafile by merging
 * this script and datafile_copy.sql.
 */
define task_id = &3
define is_cdb_supported = &6
define common_path = '&5'
@"&common_path/common.sql"

/* Setting auto print to on as this will print the select outputs to stdout. */
SET AUTOPRINT ON;

/* Refcursor to iterate and print the result set. */
var v_rc refcursor;

DECLARE
  sql_stmt   VARCHAR2(2000);
  cdb_clause VARCHAR2(100);
BEGIN
  IF '&is_cdb_supported' = '1' THEN
    cdb_clause := ', da.CON_ID';
  ELSE
    cdb_clause := ', 0';
  END IF;

sql_stmt := 'select /*+ RULE*/
    bp.HANDLE,
    bd.RECID,
    bd.STAMP,
    bp.TAG,
    bd.INCREMENTAL_LEVEL,
    bd.RESETLOGS_CHANGE#,
    to_char(cast(bd.RESETLOGS_TIME as timestamp) at time zone ''UTC'', ''&date_format''),
    bd.CHECKPOINT_CHANGE#,
    to_char(cast(bd.CHECKPOINT_TIME as timestamp) at time zone ''UTC'', ''&date_format''),
    bd.CHECKPOINT_TIME,
    bd.ABSOLUTE_FUZZY_CHANGE#,
    0, /* RECOVERY_FUZZY_CHANGE */
    0, /* RECOVERY_FUZZY_TIME */
    ''NO'', /* ONLINE_FUZZY */
    ''NO'', /* BACKUP_FUZZY */
    bd.MARKED_CORRUPT,
    bd.MEDIA_CORRUPT,
    bd.LOGICALLY_CORRUPT,
    ''A'', /* STATUS */
    bd.BLOCKS,
    bd.BLOCK_SIZE,
    da.NAME,
    da.ENABLED,
    da.CHECKPOINT_CHANGE#' || cdb_clause || ', da.FILE#
  from V$BACKUP_PIECE bp, V$BACKUP_SET_DETAILS bs, V$BACKUP_DATAFILE bd, V$DATAFILE da
  where (bs.SESSION_RECID, bs.SESSION_STAMP) IN (
    select /*+ RULE*/distinct SESSION_RECID, SESSION_STAMP
    from V$RMAN_STATUS
    where command_id=''&task_id'') and
    bp.SET_STAMP = bs.SET_STAMP and
    bp.SET_COUNT = bs.SET_COUNT and
    bd.SET_STAMP = bs.SET_STAMP and
    bd.SET_COUNT = bs.SET_COUNT and
    bd.FILE# = da.FILE# and
    bd.CREATION_CHANGE# = da.CREATION_CHANGE#';
OPEN :v_rc FOR sql_stmt;
END;
/
quit;
