/**
 * Copyright 2018 Cohesity Inc.
 *
 * Author : Vivek Velankar
 *
 * Get the datafile information for the current task ID. We are fetching
 * some extra information now which may not be needed.
 */
define task_id = &3
define column_separator = &4
define common_path = &5
define is_cdb_supported = &6
@&common_path/common.sql

/* Setting auto print to on as this will print the select outputs to stdout. */
SET AUTOPRINT ON;

/* Refcursor to iterate and print the result set. */
var v_rc refcursor;

DECLARE
  sql_stmt   VARCHAR2(2000);
  cdb_clause VARCHAR2(100);
BEGIN
  IF '&is_cdb_supported' = '1' THEN
    cdb_clause := 'f.CON_ID';
  ELSE
    cdb_clause := '0';
  END IF;

sql_stmt := 'select /*+ RULE*/
-- Eliminate any possible line feeds (carriage return characters)
-- start REPLACE(REPLACE( <column>, CHR(10) ), CHR(13) )
replace(replace(
-- Column#: 1
d.NAME
||''&column_separator''||
-- Column#: 2
d.RECID
||''&column_separator''||
-- Column#: 3
d.STAMP
||''&column_separator''||
-- Column#: 4
d.TAG
||''&column_separator''||
-- Column#: 5
d.INCREMENTAL_LEVEL
||''&column_separator''||
-- Column#: 6
d.RESETLOGS_CHANGE#
||''&column_separator''||
-- Column#: 7
to_char(cast(d.RESETLOGS_TIME as timestamp) at time zone ''UTC'', ''&date_format'')
||''&column_separator''||
-- Column#: 8
d.CHECKPOINT_CHANGE#
||''&column_separator''||
-- Column#: 9
to_char(cast(d.CHECKPOINT_TIME as timestamp) at time zone ''UTC'', ''&date_format'')
||''&column_separator''||
-- Column#: 10
d.CHECKPOINT_TIME
||''&column_separator''||
-- Column#: 11
d.ABSOLUTE_FUZZY_CHANGE#
||''&column_separator''||
-- Column#: 12
d.RECOVERY_FUZZY_CHANGE#
||''&column_separator''||
-- Column#: 13
d.RECOVERY_FUZZY_TIME
||''&column_separator''||
-- Column#: 14
d.ONLINE_FUZZY
||''&column_separator''||
-- Column#: 15
d.BACKUP_FUZZY
||''&column_separator''||
-- Column#: 16
d.MARKED_CORRUPT
||''&column_separator''||
-- Column#: 17
d.MEDIA_CORRUPT
||''&column_separator''||
-- Column#: 18
d.LOGICALLY_CORRUPT
||''&column_separator''||
-- Column#: 19
d.STATUS
||''&column_separator''||
-- Column#: 20
d.BLOCKS
||''&column_separator''||
-- Column#: 21
d.BLOCK_SIZE
||''&column_separator''||
-- Column#: 22
f.NAME
||''&column_separator''||
-- Column#: 23
f.ENABLED
||''&column_separator''||
-- Column#: 24
f.CHECKPOINT_CHANGE#
||''&column_separator''||
-- Column#: 25
' || cdb_clause || '
||''&column_separator''||
-- Column#: 26
f.FILE#
, CHR(10) ), CHR(13) )
from V$DATAFILE_COPY d, V$DATAFILE f
where f.FILE# = d.FILE# and
      f.RFILE# = d.RFILE# and
      f.CREATION_CHANGE# = d.CREATION_CHANGE# and
      d.STATUS = ''A'' and
      d.INCREMENTAL_LEVEL is not NULL and
      d.RMAN_STATUS_RECID > 0 and
      d.RMAN_STATUS_STAMP > 0 and
      d.TAG=upper(''&task_id'')';
OPEN :v_rc FOR sql_stmt;
END;
/
quit;
