#!/bin/bash
# Copyright 2019 Cohesity Inc.
#
# Author Prajakta Ayachit
# This shell version of progress.sql.
# Fetches the progress for each channel for the corresponding Session list and
# provides an aggregated output.
#
# Note: common.sql takes 3rd arguement for 'task_id'. Since 'task_id' is not
# needed for querying progress, that argument is sent as "dummy".
#
# In the below query we return one row for each operation like incremental
# backup, incremental merge, archivelog backup and datafile restore
# We get numbers for each above operation in different blocks sizes, hence
# capturing the block size as well.
# There are other ways like using with clause or using v$rman_status, but they
# dont work if the DB is not opened(in mount state).
#
# For more reference - http://bit.ly/3b7aOoV
#
set -e

export COMMON_PATH=$7
export SID_LIST=$5
export SESSION_LIST=$8
export CONNECT_STRING=$2
$1 -S <<EOF
$CONNECT_STRING
@$COMMON_PATH/common.sql $3 $4 "dummy" $6;

SELECT /*+ RULE*/
opname,s1,s2,
(SELECT /*+ RULE*/ SUM(BYTES) from V\$datafile) df_sz,
(SELECT /*+ RULE*/ ROUND(AVG(BLOCK_SIZE)) from V\$datafile) df_block_sz,
(SELECT /*+ RULE*/ COALESCE(NULLIF(SUM(BLOCKS), 0), 0) from V\$ARCHIVED_LOG where
BACKUP_COUNT=0 and
upper(STANDBY_DEST)='NO' and
upper(STATUS)!='D' and
upper(DELETED)='NO') arch_block,
(SELECT /*+ RULE*/ BLOCK_SIZE from V\$ARCHIVED_LOG where rownum=1) arch_block_sz
FROM
(SELECT /*+ RULE*/ opname,sum(sofar) s1, sum(TOTALWORK) s2 FROM
GV\$SESSION_LONGOPS
WHERE
SID in ($(echo -e $SID_LIST)) and
SERIAL# in ($(echo -e $SESSION_LIST)) and
TOTALWORK != 0 and
CONTEXT = 1 and
(opname like '%incremental datafile backup%' or
opname like '%incremental datafile restore%' or
opname like '%archived log backup%' or
opname like '%datafile copy%') group by opname);
exit;
EOF
