#!/bin/bash
# Copyright 2018 Cohesity Inc.
#
# Author Vivek Velankar
# This is a wrapper script for invoking the sql script with correct parameters.
#
# Example invocation:-
# $0 sqlplus $ORACLE_HOME ORA3 / /home/oracle/stitching
#     rman_status.sql "#__ch__#" 1111 2222 vvv_rman

# Read the stdin as first step.
read connect_string;

# Exit from the script if any of the step fails.
set -e

LOG_FILE=""

# Which OS Cohesity agent is running on.
OS=$(uname -a | cut -d " " -f 1)

if [ ${OS} = "AIX" ]; then
  # TODO(aabhas): find replacement for readlink on AIX.
  current_dir=$(dirname $0)
else
  current_dir=$(dirname `readlink -f $0`)
fi

SCRIPT_NAME=`basename "$0"`
# Source needed library functions.
. $current_dir/common_utils.sh

usage() {
  echo "Invoke the script with following arguments:-"
  echo -e "\t -S Path to SQLPLUS binary."
  echo -e "\t -H Path to ORACLE home directory."
  echo -e "\t -I Oracle database SID value."
  echo -e "\t -P Path to SQL script directory."
  echo -e "\t -s Script name to execute."
  echo -e "\t -D Delimiter used in the output."
  echo -e "\t -O OS error code."
  echo -e "\t -Q SQL error code."
  echo -e "\t -M Command ID Value. Also used as argument1 in some cases."
  echo -e "\t -N Extra argument, if required."
  echo -e "\t -U Use heredoc script for doing sqlplus work"
}

#### Main

while getopts "S:H:I:C:P:s:D:O:Q:M:N:U" option; do
  case $option in
    S)
      SQLPLUS_PATH=$OPTARG;;
    H)
      export ORACLE_HOME=$OPTARG;;
    I)
      export ORACLE_SID=$OPTARG;;
    P)
      sql_script_path=$OPTARG;;
    s)
      script=$OPTARG;;
    D)
      delim=$OPTARG;;
    O)
      os_error=$OPTARG;;
    Q)
      sql_error=$OPTARG;;
    M)
      ID=$OPTARG;;
    N)
      args=$OPTARG;;
    U)
      use_heredoc=true;;
    *) echo "Invalid option passed."; usage; exit 1;;
  esac
done

export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:${ORACLE_HOME}/lib"
export PATH="$PATH:${ORACLE_HOME}/bin"
export NLS_DATE_FORMAT='DD:MM:YYYY-HH24:MI:SS'

# Modify how to invoke Oracle binaries if the agent is installed with 'root'
setup_invoke_oracle_binaries

if [ "x$ID" == "x" ]; then
  ID="NA"
fi

f_set_privilege "$ORACLE_HOME" "$connect_string"

if [ "x$use_heredoc" == "x" ]; then

  sql_cmd="$SQLPLUS_PATH -S $connect_string $sqlplus_privilege @$sql_script_path/$script
           $os_error $sql_error $ID $delim $sql_script_path"

  if [ "x$args" != "x" ]; then
    sql_cmd="$sql_cmd $args"
  fi

  $sql_cmd
else

  . ${sql_script_path}/${script} "${SQLPLUS_PATH}" "$connect_string $sqlplus_privilege" $os_error $sql_error $ID $delim $sql_script_path $args
fi
