#!/bin/bash
#
# Copyright 2016 Cohesity Inc.
#
# Author: Sachin Gaikwad (sachin@cohesity.com)
#
# Description:
# Contains common code to setup some environment variables used in installer.

# This scripts has few variables which are set to <*_TEMPLATE> values. These are
# filled by external scripts (setup.sh/installer) based on user input from
# command-line args or because we discover few things dynamically e.g.
# AGENT_SOFTWARE_VERSION is discovered dynamically by using "--version" gflag of
# linux agent binary.
#

set -o nounset
#set -e

# General.
LINUX_DISTRO=""

# Following is NOT same as what we have on Cohesity Cluster. We do not create
# toolchain version specific dir for installing agent - because it is not
# required. Few scripts (like vm_mounter.sh expect this variable to be set), so
# for now setting it to COHESITY_INSTALL_DIR/software/crux directory. This way any
# reference to $COHESITY_TOOLCHAIN_VERSION_DIR/bin continues to work in
# vm_mounter.sh script.

# Cohesity Linux Agent.
AGENT_STARTUP_SCRIPT_NAME="linux_agent.sh"
AGENT_SERVICE_NAME="cohesity-agent"
AGENT_EXEC_NAME="linux_agent_exec"
AGENT_BUILD_TYPE=""

# systemd related vars.
AGENT_SERVICE_DIR="/var/run/cohesity-agent"
AGENT_SERVICE_PIDFILE="${AGENT_SERVICE_DIR}/cohesity-agent.pid"
SYSTEMD_SERVICE_FILE_DIR="/usr/lib/systemd/system"
SYSTEMD_SERVICE_FILE="$SYSTEMD_SERVICE_FILE_DIR/${AGENT_SERVICE_NAME}.service"
UPSTART_SERVICE_FILE="/etc/init/${AGENT_SERVICE_NAME}.conf"
SYSTEMD_PRIVILEGED_VERSION=237
SYSTEMD_ROOT_VERSION=219

# Linux commands paths.
# These paths are used by linux_agent_exec. On Ubuntu/Centos, we have seen that
# paths differ for these commands: /bin/ vs /usr/bin/.
MOUNT_CMD=$(whereis mount | awk '{ print $2 }')
UMOUNT_CMD=$(whereis umount | awk '{ print $2 }')
FINDMNT_CMD=$(whereis findmnt | awk '{ print $2 }')

GNU_COREUTILS_VERSION=""

# COHESITY_MAX_LOG_SIZE is the maximum size of logs. For glog C++ library this
# value is interpreted in MB. For Go glog, the size is interpreted in bytes and
# so it converted to MB in code.
COHESITY_MAX_LOG_SIZE=30
